@@ -17,6 +17,7 @@
 package org.apache.catalina.authenticator;
 
 import java.io.IOException;
+import java.io.Serial;
 import java.io.StringReader;
 import java.nio.charset.StandardCharsets;
 import java.security.NoSuchAlgorithmException;
@@ -263,16 +264,14 @@ public class DigestAuthenticator extends AuthenticatorBase {
     @Override
     protected boolean doAuthenticate(Request request, HttpServletResponse response) throws IOException {
 
-        /*
-         * Reauthentication using the cached user name and password (if any) is not enabled for DIGEST authentication.
-         * This was an historical design decision made because DIGEST authentication is viewed as more secure than
-         * BASIC/FORM.
-         *
-         * However, reauthentication was introduced to handle the case where the Realm took additional actions on
-         * authentication. Reauthenticating with the cached user name and password should be sufficient for DIGEST in
-         * that scenario. However, the original behaviour to reauthenticate has been retained in case of any (very
-         * unlikely) backwards compatibility issues.
-         */
+        // NOTE: We don't try to reauthenticate using any existing SSO session,
+        // because that will only work if the original authentication was
+        // BASIC or FORM, which are less secure than the DIGEST auth-type
+        // specified for this webapp
+        //
+        // Change to true below to allow previous FORM or BASIC authentications
+        // to authenticate users for this webapp
+        // TODO make this a configurable attribute (in SingleSignOn??)
         if (checkForCachedAuthentication(request, response, false)) {
             return true;
         }
@@ -316,42 +315,6 @@ public class DigestAuthenticator extends AuthenticatorBase {
     // ------------------------------------------------------ Protected Methods
 
 
-    /**
-     * Removes the quotes on a string. RFC2617 states quotes are optional for all parameters except realm.
-     *
-     * @param quotedString   The quoted string
-     * @param quotesRequired <code>true</code> if quotes were required
-     *
-     * @return The unquoted string
-     *
-     * @deprecated This will be removed in Tomcat 11 onwards. Unused.
-     */
-    @Deprecated
-    protected static String removeQuotes(String quotedString, boolean quotesRequired) {
-        // support both quoted and non-quoted
-        if (quotedString.length() > 0 && quotedString.charAt(0) != '"' && !quotesRequired) {
-            return quotedString;
-        } else if (quotedString.length() > 2) {
-            return quotedString.substring(1, quotedString.length() - 1);
-        } else {
-            return "";
-        }
-    }
-
-    /**
-     * Removes the quotes on a string.
-     *
-     * @param quotedString The quoted string
-     *
-     * @return The unquoted string
-     *
-     * @deprecated This will be removed in Tomcat 11 onwards. Unused.
-     */
-    @Deprecated
-    protected static String removeQuotes(String quotedString) {
-        return removeQuotes(quotedString, false);
-    }
-
     /**
      * Generate a unique token. The token is generated according to the following pattern. NOnceToken = Base64 (
      * NONCE_DIGEST ( client-IP ":" time-stamp ":" private-key ) ).
@@ -461,6 +424,7 @@ public class DigestAuthenticator extends AuthenticatorBase {
          */
         nonces = new LinkedHashMap<>() {
 
+            @Serial
             private static final long serialVersionUID = 1L;
             private static final long LOG_SUPPRESS_TIME = 5 * 60 * 1000;
 
@@ -564,12 +528,6 @@ public class DigestAuthenticator extends AuthenticatorBase {
             return true;
         }
 
-        @Deprecated
-        public boolean validate(Request request) {
-            List<AuthDigest> fallbackList = Arrays.asList(FALLBACK_DIGEST);
-            return validate(request, fallbackList);
-        }
-
         public boolean validate(Request request, List<AuthDigest> algorithms) {
             if ((userName == null) || (realmName == null) || (nonce == null) || (uri == null) || (response == null)) {
                 return false;
