@@ -154,7 +154,6 @@ public class Http11Processor extends AbstractProcessor {
     private final HttpParser httpParser;
 
 
-    @SuppressWarnings("deprecation")
     public Http11Processor(AbstractHttp11Protocol<?> protocol, Adapter adapter) {
         super(adapter);
         this.protocol = protocol;
@@ -166,8 +165,7 @@ public class Http11Processor extends AbstractProcessor {
         }
         this.httpParser = httpParser;
 
-        inputBuffer = new Http11InputBuffer(request, protocol.getMaxHttpRequestHeaderSize(),
-                protocol.getRejectIllegalHeader(), httpParser);
+        inputBuffer = new Http11InputBuffer(request, protocol.getMaxHttpRequestHeaderSize(), httpParser);
         request.setInputBuffer(inputBuffer);
 
         outputBuffer = new Http11OutputBuffer(response, protocol.getMaxHttpResponseHeaderSize());
@@ -609,11 +607,6 @@ public class Http11Processor extends AbstractProcessor {
             http09 = true;
             http11 = false;
             keepAlive = false;
-            if (!Method.GET.equals(request.getMethod())) {
-                // Send 400, GET is the only allowed method for HTTP/0.9
-                response.setStatus(400);
-                setErrorState(ErrorState.CLOSE_CLEAN, null);
-            }
         } else {
             // Unsupported protocol
             http09 = false;
@@ -631,7 +624,6 @@ public class Http11Processor extends AbstractProcessor {
     /**
      * After reading the request headers, we have to set up the request filters.
      */
-    @SuppressWarnings("deprecation")
     private void prepareRequest() throws IOException {
 
         if (protocol.isSSLEnabled()) {
@@ -743,19 +735,10 @@ public class Http11Processor extends AbstractProcessor {
                         // Any host in the request line must be consistent with
                         // the Host header
                         if (!hostValueMB.getByteChunk().equalsIgnoreCase(uriB, uriBCStart + pos, slashPos - pos)) {
-                            if (protocol.getAllowHostHeaderMismatch()) {
-                                // The requirements of RFC 2616 are being
-                                // applied. If the host header and the request
-                                // line do not agree, the request line takes
-                                // precedence
-                                hostValueMB = headers.setValue("host");
-                                hostValueMB.setBytes(uriB, uriBCStart + pos, slashPos - pos);
-                            } else {
-                                // The requirements of RFC 7230 are being
-                                // applied. If the host header and the request
-                                // line do not agree, trigger a 400 response.
-                                badRequest("http11processor.request.inconsistentHosts");
-                            }
+                            // The requirements of RFC 7230 are being
+                            // applied. If the host header and the request
+                            // line do not agree, trigger a 400 response.
+                            badRequest("http11processor.request.inconsistentHosts");
                         }
                     }
                 } else {
@@ -792,11 +775,6 @@ public class Http11Processor extends AbstractProcessor {
         // Validate host name and extract port if present
         parseHost(hostValueMB);
 
-        // Match host name with SNI if required
-        if (!protocol.checkSni(socketWrapper.getSniHostName(), request.serverName().toString())) {
-            badRequest("http11processor.request.sni");
-        }
-
         if (!getErrorState().isIoAllowed()) {
             getAdapter().log(request, response, 0);
         }
