@@ -19,7 +19,7 @@ package org.apache.jasper.compiler;
 import java.io.CharArrayWriter;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.security.AccessController;
+import java.io.Serial;
 import java.util.Collection;
 
 import javax.xml.parsers.SAXParser;
@@ -36,8 +36,6 @@ import org.apache.tomcat.Jar;
 import org.apache.tomcat.util.descriptor.DigesterFactory;
 import org.apache.tomcat.util.descriptor.LocalResolver;
 import org.apache.tomcat.util.descriptor.tld.TldResourcePath;
-import org.apache.tomcat.util.security.PrivilegedGetTccl;
-import org.apache.tomcat.util.security.PrivilegedSetTccl;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
 import org.xml.sax.Locator;
@@ -409,7 +407,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
         }
 
         if (tagDependentNesting > 0 || pageInfo.isELIgnored() || current instanceof Node.ScriptingElement) {
-            if (charBuffer.length() > 0) {
+            if (!charBuffer.isEmpty()) {
                 @SuppressWarnings("unused")
                 Node unused = new Node.TemplateText(charBuffer.toString(), startMark, current);
             }
@@ -717,108 +715,120 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
 
         Node node;
 
-        if (localName.equals(ROOT_ACTION)) {
-            if (!(current instanceof Node.Root)) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.nested_jsproot"), locator);
+        switch (localName) {
+            case ROOT_ACTION -> {
+                if (!(current instanceof Node.Root)) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.nested_jsproot"), locator);
+                }
+                node = new Node.JspRoot(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+                if (isTop) {
+                    pageInfo.setHasJspRoot(true);
+                }
             }
-            node = new Node.JspRoot(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-            if (isTop) {
-                pageInfo.setHasJspRoot(true);
+            case PAGE_DIRECTIVE_ACTION -> {
+                if (isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.istagfile", localName), locator);
+                }
+                node = new Node.PageDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+                String imports = nonTaglibAttrs.getValue("import");
+                // There can only be one 'import' attribute per page directive
+                if (imports != null) {
+                    ((Node.PageDirective) node).addImport(imports);
+                }
             }
-        } else if (localName.equals(PAGE_DIRECTIVE_ACTION)) {
-            if (isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.istagfile", localName), locator);
+            case INCLUDE_DIRECTIVE_ACTION -> {
+                node = new Node.IncludeDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start,
+                        current);
+                processIncludeDirective(nonTaglibAttrs.getValue("file"), node);
             }
-            node = new Node.PageDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-            String imports = nonTaglibAttrs.getValue("import");
-            // There can only be one 'import' attribute per page directive
-            if (imports != null) {
-                ((Node.PageDirective) node).addImport(imports);
+            case DECLARATION_ACTION -> {
+                if (scriptlessBodyNode != null) {
+                    // We're nested inside a node whose body is
+                    // declared to be scriptless
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+                }
+                node = new Node.Declaration(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
             }
-        } else if (localName.equals(INCLUDE_DIRECTIVE_ACTION)) {
-            node = new Node.IncludeDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-            processIncludeDirective(nonTaglibAttrs.getValue("file"), node);
-        } else if (localName.equals(DECLARATION_ACTION)) {
-            if (scriptlessBodyNode != null) {
-                // We're nested inside a node whose body is
-                // declared to be scriptless
-                throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+            case SCRIPTLET_ACTION -> {
+                if (scriptlessBodyNode != null) {
+                    // We're nested inside a node whose body is
+                    // declared to be scriptless
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+                }
+                node = new Node.Scriptlet(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
             }
-            node = new Node.Declaration(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(SCRIPTLET_ACTION)) {
-            if (scriptlessBodyNode != null) {
-                // We're nested inside a node whose body is
-                // declared to be scriptless
-                throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+            case EXPRESSION_ACTION -> {
+                if (scriptlessBodyNode != null) {
+                    // We're nested inside a node whose body is
+                    // declared to be scriptless
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+                }
+                node = new Node.Expression(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
             }
-            node = new Node.Scriptlet(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(EXPRESSION_ACTION)) {
-            if (scriptlessBodyNode != null) {
-                // We're nested inside a node whose body is
-                // declared to be scriptless
-                throw new SAXParseException(Localizer.getMessage("jsp.error.no.scriptlets", localName), locator);
+            case USE_BEAN_ACTION ->
+                node = new Node.UseBean(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case SET_PROPERTY_ACTION ->
+                node = new Node.SetProperty(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case GET_PROPERTY_ACTION ->
+                node = new Node.GetProperty(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case INCLUDE_ACTION ->
+                node = new Node.IncludeAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case FORWARD_ACTION ->
+                node = new Node.ForwardAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case PARAM_ACTION ->
+                node = new Node.ParamAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case TEXT_ACTION -> node = new Node.JspText(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case BODY_ACTION -> node = new Node.JspBody(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case ATTRIBUTE_ACTION ->
+                node = new Node.NamedAttribute(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case OUTPUT_ACTION ->
+                node = new Node.JspOutput(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            case TAG_DIRECTIVE_ACTION -> {
+                if (!isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName),
+                            locator);
+                }
+                node = new Node.TagDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+                String imports = nonTaglibAttrs.getValue("import");
+                // There can only be one 'import' attribute per tag directive
+                if (imports != null) {
+                    ((Node.TagDirective) node).addImport(imports);
+                }
             }
-            node = new Node.Expression(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(USE_BEAN_ACTION)) {
-            node = new Node.UseBean(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(SET_PROPERTY_ACTION)) {
-            node = new Node.SetProperty(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(GET_PROPERTY_ACTION)) {
-            node = new Node.GetProperty(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(INCLUDE_ACTION)) {
-            node = new Node.IncludeAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(FORWARD_ACTION)) {
-            node = new Node.ForwardAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(PARAM_ACTION)) {
-            node = new Node.ParamAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(PARAMS_ACTION)) {
-            node = new Node.ParamsAction(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(PLUGIN_ACTION)) {
-            node = new Node.PlugIn(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(TEXT_ACTION)) {
-            node = new Node.JspText(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(BODY_ACTION)) {
-            node = new Node.JspBody(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(ATTRIBUTE_ACTION)) {
-            node = new Node.NamedAttribute(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(OUTPUT_ACTION)) {
-            node = new Node.JspOutput(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(TAG_DIRECTIVE_ACTION)) {
-            if (!isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName), locator);
+            case ATTRIBUTE_DIRECTIVE_ACTION -> {
+                if (!isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName),
+                            locator);
+                }
+                node = new Node.AttributeDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start,
+                        current);
             }
-            node = new Node.TagDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-            String imports = nonTaglibAttrs.getValue("import");
-            // There can only be one 'import' attribute per tag directive
-            if (imports != null) {
-                ((Node.TagDirective) node).addImport(imports);
+            case VARIABLE_DIRECTIVE_ACTION -> {
+                if (!isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName),
+                            locator);
+                }
+                node = new Node.VariableDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start,
+                        current);
             }
-        } else if (localName.equals(ATTRIBUTE_DIRECTIVE_ACTION)) {
-            if (!isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName), locator);
+            case INVOKE_ACTION -> {
+                if (!isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName),
+                            locator);
+                }
+                node = new Node.InvokeAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
             }
-            node = new Node.AttributeDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(VARIABLE_DIRECTIVE_ACTION)) {
-            if (!isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName), locator);
+            case DOBODY_ACTION -> {
+                if (!isTagFile) {
+                    throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName),
+                            locator);
+                }
+                node = new Node.DoBodyAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
             }
-            node = new Node.VariableDirective(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(INVOKE_ACTION)) {
-            if (!isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName), locator);
-            }
-            node = new Node.InvokeAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(DOBODY_ACTION)) {
-            if (!isTagFile) {
-                throw new SAXParseException(Localizer.getMessage("jsp.error.action.isnottagfile", localName), locator);
-            }
-            node = new Node.DoBodyAction(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(ELEMENT_ACTION)) {
-            node = new Node.JspElement(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else if (localName.equals(FALLBACK_ACTION)) {
-            node = new Node.FallBackAction(qName, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
-        } else {
-            throw new SAXParseException(Localizer.getMessage("jsp.error.xml.badStandardAction", localName), locator);
+            case ELEMENT_ACTION ->
+                node = new Node.JspElement(qName, nonTaglibAttrs, nonTaglibXmlnsAttrs, taglibAttrs, start, current);
+            default -> throw new SAXParseException(Localizer.getMessage("jsp.error.xml.badStandardAction", localName),
+                    locator);
         }
 
         return node;
@@ -1023,21 +1033,10 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
      */
     private static SAXParser getSAXParser(boolean validating, JspDocumentParser jspDocParser) throws Exception {
 
-        ClassLoader original;
         Thread currentThread = Thread.currentThread();
-        if (Constants.IS_SECURITY_ENABLED) {
-            PrivilegedGetTccl pa = new PrivilegedGetTccl(currentThread);
-            original = AccessController.doPrivileged(pa);
-        } else {
-            original = currentThread.getContextClassLoader();
-        }
+        ClassLoader original = currentThread.getContextClassLoader();
         try {
-            if (Constants.IS_SECURITY_ENABLED) {
-                PrivilegedSetTccl pa = new PrivilegedSetTccl(currentThread, JspDocumentParser.class.getClassLoader());
-                AccessController.doPrivileged(pa);
-            } else {
-                currentThread.setContextClassLoader(JspDocumentParser.class.getClassLoader());
-            }
+            currentThread.setContextClassLoader(JspDocumentParser.class.getClassLoader());
 
             SAXParserFactory factory = SAXParserFactory.newInstance();
 
@@ -1061,12 +1060,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
 
             return saxParser;
         } finally {
-            if (Constants.IS_SECURITY_ENABLED) {
-                PrivilegedSetTccl pa = new PrivilegedSetTccl(currentThread, original);
-                AccessController.doPrivileged(pa);
-            } else {
-                currentThread.setContextClassLoader(original);
-            }
+            currentThread.setContextClassLoader(original);
         }
     }
 
@@ -1075,6 +1069,7 @@ class JspDocumentParser extends DefaultHandler2 implements TagConstants {
      */
     private static class EnableDTDValidationException extends SAXParseException {
 
+        @Serial
         private static final long serialVersionUID = 1L;
 
         EnableDTDValidationException(String message, Locator loc) {
