@@ -46,10 +46,7 @@ import jakarta.servlet.jsp.JspContext;
 import jakarta.servlet.jsp.JspFactory;
 import jakarta.servlet.jsp.JspWriter;
 import jakarta.servlet.jsp.PageContext;
-import jakarta.servlet.jsp.el.ELException;
-import jakarta.servlet.jsp.el.ExpressionEvaluator;
 import jakarta.servlet.jsp.el.NotFoundELResolver;
-import jakarta.servlet.jsp.el.VariableResolver;
 import jakarta.servlet.jsp.tagext.BodyContent;
 import jakarta.servlet.jsp.tagext.JspTag;
 import jakarta.servlet.jsp.tagext.VariableInfo;
@@ -61,8 +58,7 @@ import org.apache.jasper.compiler.Localizer;
  * handler implementation. It wraps the Invoking JSP Context, that is, the JspContext instance passed to the tag handler
  * by the invoking page via setJspContext().
  */
-@SuppressWarnings("deprecation") // Have to support old JSP EL API
-public class JspContextWrapper extends PageContext implements VariableResolver {
+public class JspContextWrapper extends PageContext {
 
     private final JspTag jspTag;
 
@@ -318,12 +314,6 @@ public class JspContextWrapper extends PageContext implements VariableResolver {
         invokingJspCtxt.include(relativeUrlPath, false);
     }
 
-    @Override
-    @Deprecated
-    public VariableResolver getVariableResolver() {
-        return this;
-    }
-
     @Override
     public BodyContent pushBody() {
         return invokingJspCtxt.pushBody();
@@ -339,12 +329,6 @@ public class JspContextWrapper extends PageContext implements VariableResolver {
         return invokingJspCtxt.popBody();
     }
 
-    @Override
-    @Deprecated
-    public ExpressionEvaluator getExpressionEvaluator() {
-        return invokingJspCtxt.getExpressionEvaluator();
-    }
-
     @Override
     public void handlePageException(Exception ex) throws IOException, ServletException {
         // Should never be called since handleException() called with a
@@ -357,16 +341,6 @@ public class JspContextWrapper extends PageContext implements VariableResolver {
         invokingJspCtxt.handlePageException(t);
     }
 
-    /**
-     * VariableResolver interface
-     */
-    @Override
-    @Deprecated
-    public Object resolveVariable(String pName) throws ELException {
-        ELContext ctx = this.getELContext();
-        return ctx.getELResolver().getValue(ctx, null, pName);
-    }
-
     /**
      * Synchronize variables at begin of tag file
      */
