@@ -516,8 +516,10 @@ public class JspServletWrapper {
     protected JasperException handleJspException(Exception ex) {
         try {
             Throwable realException = ex;
-            if (ex instanceof ServletException) {
-                realException = ((ServletException) ex).getRootCause();
+            // Unwrap Servlet exception once
+            if (ex instanceof ServletException servletException
+                    && servletException.getRootCause() != null) {
+                realException = servletException.getRootCause();
             }
 
             // Find the first stack frame that represents code generated by
