@@ -19,16 +19,7 @@ package org.apache.tomcat.websocket.server;
 import jakarta.servlet.http.HttpSessionEvent;
 import jakarta.servlet.http.HttpSessionListener;
 
-public class WsSessionListener implements HttpSessionListener {
-
-    private final WsServerContainer wsServerContainer;
-
-
-    public WsSessionListener(WsServerContainer wsServerContainer) {
-        this.wsServerContainer = wsServerContainer;
-    }
-
-
+public record WsSessionListener(WsServerContainer wsServerContainer) implements HttpSessionListener {
     @Override
     public void sessionDestroyed(HttpSessionEvent se) {
         wsServerContainer.closeAuthenticatedSession(se.getSession().getId());
